@@ -38,6 +38,15 @@ class Jp2k(Jp2kBox):
 
     Attributes
     ----------
+    codestream
+    decoded_components
+    dtype
+    ignore_pclr_cmap_cdef
+    layer
+    ndim
+    shape
+    tilesize
+    verbose
     filename : str
         The path to the JPEG 2000 file.
     box : sequence
@@ -47,21 +56,6 @@ class Jp2k(Jp2kBox):
     shape : tuple
         Size of the image.
 
-    Properties
-    ----------
-    codestream : glymur.codestream.Codestream
-        JP2 or J2K codestream object.
-    decoded_components : sequence or None
-        If set, decode only these components.  The MCT will not be used.
-    ignore_pclr_cmap_cdef : bool
-        Whether or not to ignore the pclr, cmap, or cdef boxes during any
-        color transformation, defaults to False.
-    layer : int
-        Zero-based number of quality layer to decode.
-    verbose : bool
-        Whether or not to print informational messages produced by the
-        OpenJPEG library, defaults to false.
-
     Examples
     --------
     >>> import glymur
@@ -104,7 +98,8 @@ class Jp2k(Jp2kBox):
         plt=False, prog=None, psizes=None, psnr=None, sop=None,
         subsam=None, tlm=False,
     ):
-        """
+        """Construct a Jp2k object.
+
         Parameters
         ----------
         filename : str
@@ -139,7 +134,8 @@ class Jp2k(Jp2kBox):
             If true, use the irreversible DWT 9-7 transform.
         mct : bool, optional
             Usage of the multi component transform to write an image.  If not
-            specified, defaults to True if the color space is RGB.
+            specified, defaults to True if the color space is RGB, false if the
+            color space is grayscale.
         modesw : int, optional
             mode switch
                 1 = BYPASS(LAZY)
@@ -255,8 +251,7 @@ class Jp2k(Jp2kBox):
         self.finalize()
 
     def finalize(self, force_parse=False):
-        """
-        For now, the only task remaining is to possibly write out a
+        """For now, the only task remaining is to possibly write out a
         ResolutionBox if we were so instructed.  There could be other
         possibilities in the future.
 
@@ -290,8 +285,7 @@ class Jp2k(Jp2kBox):
         self._insert_resolution_superbox()
 
     def _insert_resolution_superbox(self):
-        """
-        As a close-out task, insert a resolution superbox into the jp2
+        """As a close-out task, insert a resolution superbox into the jp2
         header box if we were so instructed.  This requires a wrapping
         operation.
         """
@@ -319,9 +313,7 @@ class Jp2k(Jp2kBox):
         self.parse()
 
     def _validate_kwargs(self):
-        """
-        Validate keyword parameters passed to the constructor.
-        """
+        """Validate keyword parameters passed to the constructor."""
         non_cinema_args = (
             self._mct, self._cratios, self._psnr, self._irreversible,
             self._cbsize, self._eph, self._grid_offset, self._modesw,
@@ -406,8 +398,7 @@ class Jp2k(Jp2kBox):
             raise RuntimeError(msg)
 
     def _initialize_shape(self):
-        """
-        If there was no image data provided and if no shape was
+        """If there was no image data provided and if no shape was
         initially provisioned, then shape must be computed AFTER we
         have parsed the input file.
         """
@@ -442,6 +433,9 @@ class Jp2k(Jp2kBox):
 
     @property
     def ignore_pclr_cmap_cdef(self):
+        """Whether or not to ignore the pclr, cmap, or cdef boxes during any
+        color transformation, defaults to False.
+        """
         return self._ignore_pclr_cmap_cdef
 
     @ignore_pclr_cmap_cdef.setter
@@ -450,21 +444,26 @@ class Jp2k(Jp2kBox):
 
     @property
     def decoded_components(self):
+        """If set, decode only these components.  The MCT will not be used.
+        List or scalar or None (default).
+        """
         return self._decoded_components
 
     @decoded_components.setter
     def decoded_components(self, components):
 
         if components is None:
-            # this is a special case where we are restoring the original
-            # behavior of reading all bands
+            # This is ok.  It is a special case where we are restoring the
+            # original behavior of reading all bands.
             self._decoded_components = components
             return
 
         if np.isscalar(components):
+            # turn it into a list to be general
             components = [components]
 
         if any(x > len(self.codestream.segment[1].xrsiz) for x in components):
+
             msg = (
                 f"{components} has at least one invalid component, "
                 f"cannot be greater than "
@@ -472,10 +471,21 @@ class Jp2k(Jp2kBox):
             )
             raise ValueError(msg)
 
+        elif any(x < 0 for x in components):
+
+            msg = (
+                f"{components} has at least one invalid component, "
+                f"components cannot be negative."
+            )
+            raise ValueError(msg)
+
         self._decoded_components = components
 
     @property
     def layer(self):
+        """Zero-based number of quality layer to decode.  Defaults to 0, the
+        highest quality layer.
+        """
         return self._layer
 
     @layer.setter
@@ -493,9 +503,7 @@ class Jp2k(Jp2kBox):
 
     @property
     def dtype(self):
-        """
-        Datatype of the image elements.
-        """
+        """Datatype of each image component."""
         if self._dtype is None:
             c = self.get_codestream()
             bps0 = c.segment[1].bitdepth[0]
@@ -522,9 +530,7 @@ class Jp2k(Jp2kBox):
 
     @property
     def ndim(self):
-        """
-        Number of image dimensions.
-        """
+        """Number of image dimensions."""
         if self._ndim is None:
             self._ndim = len(self.shape)
 
@@ -532,33 +538,35 @@ class Jp2k(Jp2kBox):
 
     @property
     def codestream(self):
+        """JP2 or J2K codestream object (header only)."""
         if self._codestream is None:
             self._codestream = self.get_codestream(header_only=True)
         return self._codestream
 
     @property
     def tilesize(self):
+        """Dimensions of JP2 tiling."""
         return self._tilesize
 
     @property
     def verbose(self):
-        return self._verbose
-
-    @verbose.setter
-    def verbose(self, verbose):
-        """Verbosity property.
-
-        If True, print informational messages from the OPENJPEG library.
+        """Whether or not to print informational messages produced by the
+        OpenJPEG library, defaults to false.
 
         Parameters
         ----------
         verbose : {True, False}
             Set to verbose or not.
         """
+        return self._verbose
+
+    @verbose.setter
+    def verbose(self, verbose):
         self._verbose = verbose
 
     @property
     def shape(self):
+        """Dimensions of full resolution image."""
         return self._shape
 
     @shape.setter
@@ -582,9 +590,7 @@ class Jp2k(Jp2kBox):
         return '\n'.join(metadata)
 
     def get_tilewriters(self):
-        """
-        Return an object that facilitates writing tile by tile.
-        """
+        """Return an object that facilitates writing tile by tile."""
 
         if self.shape[:2] == self.tilesize:
             msg = (
@@ -646,9 +652,8 @@ class Jp2k(Jp2kBox):
             self._validate()
 
     def _validate(self):
-        """
-        Validate the JPEG 2000 outermost superbox.  These checks must be done
-        at a file level.
+        """Validate the JPEG 2000 outermost superbox.  These checks must be
+        done at a file level.
         """
         # A JP2 file must contain certain boxes.  The 2nd box must be a file
         # type box.
@@ -680,8 +685,25 @@ class Jp2k(Jp2kBox):
                 )
                 warnings.warn(msg, UserWarning)
 
-        # We need to have one and only one JP2C box if we have a JP2 file.
-        if len([box for box in self.box if box.box_id == 'jp2c']) != 1:
+        # We need to have one and only one JP2H box if we have a JP2 file.
+        num_jp2h_boxes = len([box for box in self.box if box.box_id == 'jp2h'])
+        if num_jp2h_boxes > 1:
+            msg = (
+                f"This file has {num_jp2h_boxes} JP2H boxes in the outermost "
+                "layer of boxes.  There should only be one."
+            )
+            warnings.warn(msg)
+
+        # We should have one and only one JP2C box if we have a JP2 file.
+        num_jp2c_boxes = len([box for box in self.box if box.box_id == 'jp2c'])
+        if num_jp2c_boxes > 1 and self.box[1].brand == 'jp2 ':
+            msg = (
+                f"This file has {num_jp2c_boxes} JP2C boxes (images) in the "
+                "outermost layer of boxes.  All JP2C boxes after the first "
+                "will be ignored."
+            )
+            warnings.warn(msg)
+        elif num_jp2c_boxes == 0:
             msg = (
                 "A valid JP2C box was not found in the outermost level of JP2 "
                 "boxes.  The JP2 file is invalid."
@@ -740,8 +762,7 @@ class Jp2k(Jp2kBox):
             self._cparams.rsiz = core.OPJ_PROFILE_CINEMA_4K
 
     def _populate_cparams(self, img_array):
-        """
-        Directs processing of write method arguments.
+        """Directs processing of write method arguments.
 
         Parameters
         ----------
@@ -821,16 +842,27 @@ class Jp2k(Jp2kBox):
             cparams.tile_size_on = opj2.TRUE
 
         if self._mct is None:
+
             # If the multi component transform was not specified, we infer
             # that it should be used if the color space is RGB.
             cparams.tcp_mct = 1 if self._colorspace == opj2.CLRSPC_SRGB else 0
+
+        elif self._mct and self._colorspace == opj2.CLRSPC_GRAY:
+
+            # the MCT was requested, but the colorspace is gray
+            # i.e. 1 component.  NOT ON MY WATCH!
+
+            msg = (
+                "You cannot specify usage of the multi component transform "
+                "if the colorspace is gray."
+            )
+            raise InvalidJp2kError(msg)
+
         else:
-            if self._colorspace == opj2.CLRSPC_GRAY:
-                msg = (
-                    "Cannot specify usage of the multi component transform "
-                    "if the colorspace is gray."
-                )
-                raise InvalidJp2kError(msg)
+
+            # The MCT was explicitly not specified
+            # or it was specified AND the colorspace is going to be RGB.
+            # In either case, we can use the MCT as requested.
             cparams.tcp_mct = 1 if self._mct else 0
 
         # Set defaults to lossless to begin.
@@ -878,8 +910,7 @@ class Jp2k(Jp2kBox):
         self._write_openjp2(img_array)
 
     def _validate_codeblock_size(self, cparams):
-        """
-        Code block dimensions must satisfy certain restrictions.
+        """Code block dimensions must satisfy certain restrictions.
 
         They must both be a power of 2 and the total area defined by the width
         and height cannot be either too great or too small for the codec.
@@ -907,8 +938,7 @@ class Jp2k(Jp2kBox):
                 raise InvalidJp2kError(msg)
 
     def _validate_precinct_size(self, cparams):
-        """
-        Precinct dimensions must satisfy certain restrictions if specified.
+        """Precinct dimensions must satisfy certain restrictions if specified.
 
         They must both be a power of 2 and must both be at least twice the
         size of their codeblock size counterparts.
@@ -942,16 +972,14 @@ class Jp2k(Jp2kBox):
                     raise InvalidJp2kError(msg)
 
     def _validate_image_rank(self, img_array):
-        """
-        Images must be either 2D or 3D.
+        """Images must be either 2D or 3D.
         """
         if img_array.ndim == 1 or img_array.ndim > 3:
             msg = f"{img_array.ndim}D imagery is not allowed."
             raise InvalidJp2kError(msg)
 
     def _validate_image_datatype(self, img_array):
-        """
-        Only uint8 and uint16 images are currently supported.
+        """Only uint8 and uint16 images are currently supported.
         """
         if img_array.dtype != np.uint8 and img_array.dtype != np.uint16:
             msg = (
@@ -976,8 +1004,7 @@ class Jp2k(Jp2kBox):
         self._validate_image_datatype(img_array)
 
     def _determine_colorspace(self):
-        """Determine the colorspace from the supplied inputs.
-        """
+        """Determine the colorspace from the supplied inputs."""
         if self._colorspace is None:
             # Must infer the colorspace from the image dimensions.
             if len(self.shape) < 3:
@@ -1010,9 +1037,7 @@ class Jp2k(Jp2kBox):
             self._colorspace = COLORSPACE_MAP[self._colorspace.lower()]
 
     def _write_openjp2(self, img_array):
-        """
-        Write JPEG 2000 file using OpenJPEG 2.x interface.
-        """
+        """Write JPEG 2000 file using OpenJPEG 2.x interface."""
         with ExitStack() as stack:
             image = opj2.image_create(self._comptparms, self._colorspace)
             stack.callback(opj2.image_destroy, image)
@@ -1237,9 +1262,7 @@ class Jp2k(Jp2kBox):
         return boxes
 
     def __setitem__(self, index, data):
-        """
-        Slicing protocol.
-        """
+        """Slicing protocol."""
         # Need to set this in case it is not set in the constructor.
         if self._shape is None:
             self._shape = data.shape
@@ -1262,8 +1285,9 @@ class Jp2k(Jp2kBox):
             raise ValueError(msg)
 
     def _remove_ellipsis(self, index, numrows, numcols, numbands):
-        """
-        resolve the first ellipsis in the index so that it references the image
+        """resolve the first ellipsis in the index
+
+        The intent is that it references the image
 
         Parameters
         ----------
@@ -1303,9 +1327,7 @@ class Jp2k(Jp2kBox):
         return newindex
 
     def __getitem__(self, pargs):
-        """
-        Slicing protocol.
-        """
+        """Slicing protocol."""
         if not self.path.exists():
             msg = f"Cannot read from {self.filename}, it does not yet exist."
             raise FileNotFoundError(msg)
@@ -1429,8 +1451,7 @@ class Jp2k(Jp2kBox):
         return img
 
     def read(self, **kwargs):
-        """
-        Read a JPEG 2000 image.
+        """Read a JPEG 2000 image.
 
         Returns
         -------
@@ -1446,8 +1467,7 @@ class Jp2k(Jp2kBox):
         return img
 
     def _subsampling_sanity_check(self):
-        """Check for differing subsample factors.
-        """
+        """Check for differing subsample factors."""
         if self._decoded_components is None:
             dxs = np.array(self.codestream.segment[1].xrsiz)
             dys = np.array(self.codestream.segment[1].yrsiz)
@@ -1505,8 +1525,7 @@ class Jp2k(Jp2kBox):
         return image
 
     def _read_openjp2_common(self):
-        """
-        Read a JPEG 2000 image using libopenjp2.
+        """Read a JPEG 2000 image using libopenjp2.
 
         Returns
         -------
@@ -1677,8 +1696,7 @@ class Jp2k(Jp2kBox):
         return lst
 
     def _extract_image(self, raw_image):
-        """
-        Extract unequally-sized image bands.
+        """Extract unequally-sized image bands.
 
         Parameters
         ----------
@@ -1912,8 +1930,7 @@ class Jp2k(Jp2kBox):
         self._comptparms = comptparms
 
     def _validate_nonzero_image_size(self, nrows, ncols, component_index):
-        """The image cannot have area of zero.
-        """
+        """The image cannot have area of zero."""
         if nrows == 0 or ncols == 0:
             # Letting this situation continue would segfault openjpeg.
             msg = (
@@ -1952,9 +1969,7 @@ class Jp2k(Jp2kBox):
             self._validate_jp2_colr(boxes)
 
     def _validate_jp2_colr(self, boxes):
-        """
-        Validate JP2 requirements on colour specification boxes.
-        """
+        """Validate JP2 requirements on colour specification boxes."""
         lst = [box for box in boxes if box.box_id == 'jp2h']
         jp2h = lst[0]
         for colr in [box for box in jp2h.box if box.box_id == 'colr']:
@@ -2136,8 +2151,7 @@ class Jp2k(Jp2kBox):
             raise InvalidJp2kError('There can only be one dtbl box in a file.')
 
     def _validate_jpx_compatibility(self, boxes, compatibility_list):
-        """
-        If there is a JPX box then the compatibility list must also contain
+        """If there is a JPX box then the compatibility list must also contain
         'jpx '.
         """
         JPX_IDS = ['asoc', 'nlst']
@@ -2155,8 +2169,7 @@ class Jp2k(Jp2kBox):
                 self._validate_jpx_compatibility(box.box, compatibility_list)
 
     def _validate_label(self, boxes):
-        """
-        Label boxes can only be inside association, codestream headers, or
+        """Label boxes can only be inside association, codestream headers, or
         compositing layer header boxes.
         """
         for box in boxes:
@@ -2174,8 +2187,7 @@ class Jp2k(Jp2kBox):
 
 
 class _TileWriter(object):
-    """
-    Writes tiles to file, one by one.
+    """Writes tiles to file, one by one.
 
     Attributes
     ----------
@@ -2257,8 +2269,7 @@ class _TileWriter(object):
             opj2.destroy_codec(self.codec)
 
     def setup_first_tile(self, img_array):
-        """
-        Only do these things for the first tile.
+        """Only do these things for the first tile.
         """
         self.jp2k._determine_colorspace()
         self.jp2k._populate_cparams(img_array)
@@ -2311,8 +2322,7 @@ class _TileWriter(object):
 
 
 def _set_planar_pixel_order(img):
-    """
-    Reorder the image pixels so that plane-0 comes first, then plane-1, etc.
+    """Reorder the image pixels so that plane-0 comes first, then plane-1, etc.
     This is a requirement for using opj_write_tile.
     """
     if img.ndim == 3:
