@@ -13,33 +13,13 @@ from uuid import UUID
 from glymur import Jp2k
 from glymur.core import SRGB, RESTRICTED_ICC_PROFILE
 from .lib import tiff as libtiff
+from .lib.tiff import DATATYPE2FMT
 from . import jp2box
-from ._tiff import TAGNUM2NAME
 
-# Create a mapping of tag names to tag numbers.  Make the tag names to be
-# lower-case because we need to compare against user-supplied tag names.
-TAGNAME2NUM = {v.lower(): k for k, v in TAGNUM2NAME.items()}
+# we need a lower case mapping from the tag name to the tag number
+TAGNAME2NUM = {k.lower(): v['number'] for k, v in libtiff.TAGS.items()}
 
 
-# Map the numeric TIFF datatypes to the format string used by the struct module
-# and keep track of how wide they are.
-tag_dtype = {
-    1: {'format': 'B', 'nbytes': 1},
-    2: {'format': 'B', 'nbytes': 1},
-    3: {'format': 'H', 'nbytes': 2},
-    4: {'format': 'I', 'nbytes': 4},
-    5: {'format': 'II', 'nbytes': 8},
-    7: {'format': 'B', 'nbytes': 1},
-    9: {'format': 'i', 'nbytes': 4},
-    10: {'format': 'ii', 'nbytes': 8},
-    11: {'format': 'f', 'nbytes': 4},
-    12: {'format': 'd', 'nbytes': 8},
-    13: {'format': 'I', 'nbytes': 4},
-    16: {'format': 'Q', 'nbytes': 8},
-    17: {'format': 'q', 'nbytes': 8},
-    18: {'format': 'Q', 'nbytes': 8}
-}
-
 # Mnemonics for the two TIFF format version numbers.
 _TIFF = 42
 _BIGTIFF = 43
@@ -47,6 +27,8 @@ _BIGTIFF = 43
 
 class Tiff2Jp2k(object):
     """
+    Transform a TIFF image into a JP2 image.
+
     Attributes
     ----------
     found_geotiff_tags : bool
@@ -77,6 +59,8 @@ class Tiff2Jp2k(object):
         **kwargs
     ):
         """
+        Construct the object.
+
         Parameters
         ----------
         create_exif_uuid : bool
@@ -129,11 +113,10 @@ class Tiff2Jp2k(object):
         self.setup_logging(verbosity)
 
     def _process_exclude_tags(self, exclude_tags):
-        """
-        The list of tags to exclude may be mixed type (str or integer).  There
-        is also the possibility that they may be capitalized differently than
-        our internal list, so the goal here is to convert them all to integer
-        values.
+        """The list of tags to exclude may be mixed type (str or integer).
+        There is also the possibility that they may be capitalized differently
+        than our internal list, so the goal here is to convert them all to
+        integer values.
 
         Parameters
         ----------
@@ -191,9 +174,7 @@ class Tiff2Jp2k(object):
         self.logger.addHandler(ch)
 
     def __enter__(self):
-        """
-        The Tiff2Jp2k must be used with a context manager.
-        """
+        """The Tiff2Jp2k must be used with a context manager."""
         self.tiff_fp = libtiff.open(self.tiff_filename)
         return self
 
@@ -208,17 +189,15 @@ class Tiff2Jp2k(object):
         self.rewrap_jp2()
 
     def rewrap_jp2(self):
-        """
-        These re-wrap operations should be mutually exclusive.  An ICC profile
-        should not exist in a TIFF with a colormap.
+        """These re-wrap operations should be mutually exclusive.  An ICC
+        profile should not exist in a TIFF with a colormap.
         """
         self.rewrap_for_colormap()
         self.rewrap_for_icc_profile()
 
     def rewrap_for_colormap(self):
-        """
-        If the photometric interpretation was PALETTE, then we need to insert
-        a pclr box and a cmap (component mapping box).
+        """If the photometric interpretation was PALETTE, then we need to
+        insert a pclr box and a cmap (component mapping box).
         """
 
         photo = self.get_tag_value(262)
@@ -254,9 +233,7 @@ class Tiff2Jp2k(object):
         self.jp2.parse()
 
     def rewrap_for_icc_profile(self):
-        """
-        Consume a TIFF ICC profile, if one is there.
-        """
+        """Consume a TIFF ICC profile, if one is there."""
         if self.icc_profile is None and self.include_icc_profile:
             self.logger.warning("No ICC profile was found.")
 
@@ -288,16 +265,14 @@ class Tiff2Jp2k(object):
         shutil.move(tmp_filename, self.jp2_filename)
 
     def append_extra_jp2_boxes(self):
-        """
-        Copy over the TIFF IFD.  Place it in a UUID box.  Append to the JPEG
+        """Copy over the TIFF IFD.  Place it in a UUID box.  Append to the JPEG
         2000 file.
         """
         self.append_exif_uuid_box()
         self.append_xmp_uuid_box()
 
     def append_exif_uuid_box(self):
-        """
-        Append an EXIF UUID box onto the end of the JPEG 2000 file.  It will
+        """Append an EXIF UUID box onto the end of the JPEG 2000 file.  It will
         contain metadata from the TIFF IFD.
         """
         if not self.create_exif_uuid:
@@ -334,9 +309,8 @@ class Tiff2Jp2k(object):
         self.jp2.finalize(force_parse=True)
 
     def append_xmp_uuid_box(self):
-        """
-        Append an XMP UUID box onto the end of the JPEG 2000 file if there was
-        an XMP tag in the TIFF IFD.
+        """Append an XMP UUID box onto the end of the JPEG 2000 file if there
+        was an XMP tag in the TIFF IFD.
         """
 
         if self.xmp_data is None:
@@ -354,8 +328,7 @@ class Tiff2Jp2k(object):
             uuid_box.write(f)
 
     def get_main_ifd(self):
-        """
-        Read all the tags in the main IFD.  We do it this way because of the
+        """Read all the tags in the main IFD.  We do it this way because of the
         difficulty in using TIFFGetFieldDefaulted when the datatype of a tag
         can differ.
         """
@@ -398,8 +371,7 @@ class Tiff2Jp2k(object):
                 self.icc_profile = None
 
     def read_ifd(self, tfp):
-        """
-        Process either the main IFD or an Exif IFD
+        """Process either the main IFD or an Exif IFD
 
         Parameters
         ----------
@@ -452,7 +424,7 @@ class Tiff2Jp2k(object):
             if tag == 34735:
                 self.found_geotiff_tags = True
 
-            payload_length = tag_dtype[dtype]['nbytes'] * nvalues
+            payload_length = DATATYPE2FMT[dtype]['nbytes'] * nvalues
 
             if payload_length > max_tag_payload_length:
                 # the payload does not fit into the tag entry, so use the
@@ -463,7 +435,7 @@ class Tiff2Jp2k(object):
                 tfp.seek(current_position)
 
                 # read the payload from the TIFF
-                payload_format = tag_dtype[dtype]['format'] * nvalues
+                payload_format = DATATYPE2FMT[dtype]['format'] * nvalues
                 payload = struct.unpack(
                     self.endian + payload_format, payload_buffer
                 )
@@ -473,9 +445,9 @@ class Tiff2Jp2k(object):
                 payload_buffer = tag_data[tag_payload_offset:]
 
                 # read ALL of the payload buffer
-                fmt = tag_dtype[dtype]['format']
+                fmt = DATATYPE2FMT[dtype]['format']
                 num_items = (
-                    int(max_tag_payload_length / tag_dtype[dtype]['nbytes'])
+                    int(max_tag_payload_length / DATATYPE2FMT[dtype]['nbytes'])
                 )
                 payload_format = self.endian + fmt * num_items
                 payload = struct.unpack(payload_format, payload_buffer)
@@ -502,8 +474,7 @@ class Tiff2Jp2k(object):
         return tags
 
     def _write_ifd(self, b, tags):
-        """
-        Write the IFD out to the UUIDBox.  We will always write IFDs
+        """Write the IFD out to the UUIDBox.  We will always write IFDs
         for 32-bit TIFFs, i.e. 12 byte tags, meaning just 4 bytes within
         the tag for the tag data
         """
@@ -539,13 +510,13 @@ class Tiff2Jp2k(object):
             nvalues = tags[tag]['nvalues']
             payload = tags[tag]['payload']
 
-            payload_length = tag_dtype[dtype]['nbytes'] * nvalues
+            payload_length = DATATYPE2FMT[dtype]['nbytes'] * nvalues
 
             if payload_length > max_tag_payload_length:
                 # the payload does not fit into the tag entry
 
                 # read the payload from the TIFF
-                payload_format = tag_dtype[dtype]['format'] * nvalues
+                payload_format = DATATYPE2FMT[dtype]['format'] * nvalues
 
                 # write the tag entry to the UUID
                 new_offset = after_ifd_position
@@ -559,7 +530,7 @@ class Tiff2Jp2k(object):
                 cpos = b.tell()
                 b.seek(new_offset)
 
-                format = '<' + tag_dtype[dtype]['format'] * nvalues
+                format = '<' + DATATYPE2FMT[dtype]['format'] * nvalues
                 buffer = struct.pack(format, *payload)
                 b.write(buffer)
 
@@ -570,17 +541,11 @@ class Tiff2Jp2k(object):
             else:
 
                 # the payload DOES fit into the TIFF tag entry
-
-                payload_format = (
-                    tag_dtype[dtype]['format']
-                    * int(max_tag_payload_length / tag_dtype[dtype]['nbytes'])
-                )
-
                 # write the tag metadata
                 buffer = struct.pack('<HHI', tag, dtype, nvalues)
                 b.write(buffer)
 
-                payload_format = tag_dtype[dtype]['format'] * nvalues
+                payload_format = DATATYPE2FMT[dtype]['format'] * nvalues
 
                 # we may need to alter the output format
                 if payload_format in ['H', 'B', 'I']:
@@ -602,9 +567,7 @@ class Tiff2Jp2k(object):
         return after_ifd_position
 
     def read_tiff_header(self, tfp):
-        """
-        Get the endian-ness of the TIFF, seek to the main IFD
-        """
+        """Get the endian-ness of the TIFF, seek to the main IFD"""
 
         buffer = tfp.read(4)
         data = struct.unpack('BB', buffer[:2])
@@ -637,9 +600,8 @@ class Tiff2Jp2k(object):
         tfp.seek(offset)
 
     def get_tag_value(self, tagnum):
-        """
-        Return the value associated with the tag.  Some tags are not actually
-        written into the IFD, but are instead "defaulted".
+        """Return the value associated with the tag.  Some tags are not
+        actually written into the IFD, but are instead "defaulted".
 
         Returns
         -------
@@ -658,8 +620,7 @@ class Tiff2Jp2k(object):
         return self.tags[tagnum]['payload'][0]
 
     def copy_image(self):
-        """
-        Transfer the image data from the TIFF to the JPEG 2000 file.
+        """Transfer the image data from the TIFF to the JPEG 2000 file.
         """
 
         if libtiff.isTiled(self.tiff_fp):
@@ -773,8 +734,7 @@ class Tiff2Jp2k(object):
             )
 
     def tagvalue2str(self, cls, tag_value):
-        """
-        Take a class that encompasses all of a tag's allowed values and find
+        """Take a class that encompasses all of a tag's allowed values and find
         the name of that value.
         """
 
@@ -787,8 +747,7 @@ class Tiff2Jp2k(object):
     def _write_rgba_single_tile(
         self, photo, imagewidth, imageheight, spp
     ):
-        """
-        If no jp2k tiling was specified and if the image is ok to read
+        """If no jp2k tiling was specified and if the image is ok to read
         via the RGBA interface, then just do that.  The image will be
         written with the tilesize equal to the image size, so it will
         be written using a single write operation.
@@ -832,9 +791,8 @@ class Tiff2Jp2k(object):
         self, imagewidth, imageheight, spp, jtw, jth, tw, th,
         num_jp2k_tile_cols, num_jp2k_tile_rows, dtype, use_rgba_interface
     ):
-        """
-        The input TIFF image is tiled and we are to create the output JPEG2000
-        image with specific tile dimensions.
+        """The input TIFF image is tiled and we are to create the output
+        JPEG2000 image with specific tile dimensions.
 
         Parameters
         ----------
@@ -977,8 +935,7 @@ class Tiff2Jp2k(object):
         self, imagewidth, imageheight, spp, jtw, jth, rps,
         num_jp2k_tile_cols, num_jp2k_tile_rows, dtype, use_rgba_interface
     ):
-        """
-        The input TIFF image is striped and we are to create the output
+        """The input TIFF image is striped and we are to create the output
         JPEG2000 image as a tiled JP2K.
 
         Parameters
@@ -1048,8 +1005,7 @@ class Tiff2Jp2k(object):
         self, julr, num_strips, jth, imageheight, imagewidth, rps, spp, dtype,
         use_rgba_interface
     ):
-        """
-        TIFF strips are pretty inefficient.  If our I/O was stupidly focused
+        """TIFF strips are pretty inefficient.  If our I/O was stupidly focused
         solely on each JP2K tile, we would read in each TIFF strip multiple
         times.  If instead, we read in ALL the strips that will encompass that
         current row of JP2K tiles, we will save ourselves from pushing around
@@ -1104,6 +1060,7 @@ class Tiff2Jp2k(object):
 
         # fill the multi-strip
         for stripnum in range(top_strip_num, bottom_strip_num):
+            tiff_strip = np.zeros((rps, imagewidth, spp), dtype=dtype)
 
             if use_rgba_interface:
 
