@@ -5,14 +5,12 @@ Tests for general glymur functionality.
 import collections
 import datetime
 import doctest
-import importlib.resources as ir
 from io import BytesIO
 import os
 import pathlib
 import shutil
 import struct
 import tempfile
-import time
 import unittest
 from unittest.mock import patch
 import uuid
@@ -30,7 +28,7 @@ from glymur.core import COLOR, RED, GREEN, BLUE, RESTRICTED_ICC_PROFILE
 
 from .fixtures import OPENJPEG_NOT_AVAILABLE, OPENJPEG_NOT_AVAILABLE_MSG
 
-from . import fixtures, data
+from . import fixtures
 
 
 def docTearDown(doctest_obj):  # pragma: no cover
@@ -57,7 +55,7 @@ class TestJp2k(fixtures.TestCommon):
     """These tests should be run by just about all configuration."""
 
     def setUp(self):
-        super(TestJp2k, self).setUp()
+        super().setUp()
         glymur.reset_option('all')
 
     def test_last_decomposition(self):
@@ -86,8 +84,8 @@ class TestJp2k(fixtures.TestCommon):
 
         Expected response:  the dtype property is np.uint16
         """
-        with ir.path('tests.data', 'uint16.j2k') as path:
-            j = Jp2k(path)
+        path = fixtures._path_to('uint16.j2k')
+        j = Jp2k(path)
         self.assertEqual(j.dtype, np.uint16)
 
     def test_cod_segment_not_3rd(self):
@@ -107,8 +105,8 @@ class TestJp2k(fixtures.TestCommon):
 
         Expected response:  the dtype property is np.int8
         """
-        with ir.path('tests.data', 'p0_03.j2k') as path:
-            j = Jp2k(path)
+        path = fixtures._path_to('p0_03.j2k')
+        j = Jp2k(path)
         self.assertEqual(j.dtype, np.int8)
 
     def test_dtype_inconsistent_bitdetph(self):
@@ -117,8 +115,8 @@ class TestJp2k(fixtures.TestCommon):
 
         Expected response:  TypeError when accessing the dtype property.
         """
-        with ir.path('tests.data', 'issue982.j2k') as path:
-            j = Jp2k(path)
+        path = fixtures._path_to('issue982.j2k')
+        j = Jp2k(path)
         with self.assertRaises(TypeError):
             j.dtype
 
@@ -146,8 +144,8 @@ class TestJp2k(fixtures.TestCommon):
 
         Expected response:  the ndim attribute/property is 2
         """
-        with ir.path('tests.data', 'p0_02.j2k') as path:
-            j = Jp2k(path)
+        path = fixtures._path_to('p0_02.j2k')
+        j = Jp2k(path)
         self.assertEqual(j.ndim, 2)
 
     def test_read_bands_unequal_subsampling(self):
@@ -157,8 +155,8 @@ class TestJp2k(fixtures.TestCommon):
 
         EXPECTED RESPONSE: The image is a list of arrays of unequal size.
         """
-        with ir.path(data, 'p0_06.j2k') as path:
-            d = Jp2k(path).read_bands()
+        path = fixtures._path_to('p0_06.j2k')
+        d = Jp2k(path).read_bands()
 
         actual = [band.shape for band in d]
         expected = [(129, 513), (129, 257), (65, 513), (65, 257)]
@@ -378,9 +376,9 @@ class TestJp2k(fixtures.TestCommon):
 
         EXPECTED RESULT:  RuntimeError
         """
-        with ir.path(glymur, 'jp2k.py') as path:
-            with self.assertRaises(InvalidJp2kError):
-                Jp2k(path)
+        path = fixtures._path_to('nemo.txt')
+        with self.assertRaises(InvalidJp2kError):
+            Jp2k(path)
 
     def test_file_does_not_exist(self):
         """
@@ -930,8 +928,8 @@ class TestJp2k(fixtures.TestCommon):
 
         EXPECTED RESULT:  The 2nd image read in is not the same as the first.
         """
-        with ir.path(data, 'p0_03.j2k') as path:
-            j = Jp2k(path)
+        path = fixtures._path_to('p0_03.j2k')
+        j = Jp2k(path)
         d0 = j[:]
 
         j.layer = 1
@@ -946,8 +944,8 @@ class TestJp2k(fixtures.TestCommon):
         EXPECTED RESULT:  RuntimeError when an invalid layer number is supplied
         """
         # There are 8 layers, so only values [0-7] are valid.
-        with ir.path(data, 'p0_03.j2k') as path:
-            j = Jp2k(path)
+        path = fixtures._path_to('p0_03.j2k')
+        j = Jp2k(path)
 
         with self.assertRaises(ValueError):
             j.layer = -1
@@ -965,8 +963,8 @@ class TestJp2k(fixtures.TestCommon):
 
         EXPECTED RESULT:  The default verbosity setting is False.
         """
-        with ir.path(data, 'p0_03.j2k') as path:
-            j = Jp2k(path)
+        path = fixtures._path_to('p0_03.j2k')
+        j = Jp2k(path)
 
         self.assertFalse(j.verbose)
 
@@ -976,57 +974,11 @@ class TestJp2k(fixtures.TestCommon):
 
         EXPECTED RESULT:  The default layer property value is 0.
         """
-        with ir.path(data, 'p0_03.j2k') as path:
-            j = Jp2k(path)
+        path = fixtures._path_to('p0_03.j2k')
+        j = Jp2k(path)
 
         self.assertEqual(j.layer, 0)
 
-    @unittest.skipIf(os.cpu_count() < 4, "makes no sense if 4 cores not there")
-    def test_thread_support(self):
-        """
-        SCENARIO:  Set a non-default thread support value.
-
-        EXPECTED RESULTS:  Using more threads speeds up a full read.
-        """
-        jp2 = Jp2k(self.jp2file)
-        t0 = time.time()
-        jp2[:]
-        t1 = time.time()
-        delta0 = t1 - t0
-
-        glymur.set_option('lib.num_threads', 4)
-        t0 = time.time()
-        jp2[:]
-        t1 = time.time()
-        delta1 = t1 - t0
-
-        self.assertTrue(delta1 < delta0)
-
-    @unittest.skipIf(os.cpu_count() < 4, "makes no sense if 4 cores not there")
-    def test_thread_support_on_openjpeg_lt_220(self):
-        """
-        SCENARIO:  Set number of threads on openjpeg < 2.2.0
-
-        EXPECTED RESULTS:  RuntimeError
-        """
-        with patch('glymur.jp2k.version.openjpeg_version', new='2.1.0'):
-            with self.assertRaises(RuntimeError):
-                glymur.set_option('lib.num_threads', 4)
-
-    @unittest.skipIf(os.cpu_count() < 4, "makes no sense if 4 cores not there")
-    @patch('glymur.lib.openjp2.has_thread_support')
-    def test_thread_support_not_compiled_into_library(self, mock_ts):
-        """
-        SCENARIO:  Set number of threads on openjpeg >= 2.2.0, but openjpeg
-        has not been compiled with thread support.
-
-        EXPECTED RESULTS:  RuntimeError
-        """
-        mock_ts.return_value = False
-        with patch('glymur.jp2k.version.openjpeg_version', new='2.2.0'):
-            with self.assertRaises(RuntimeError):
-                glymur.set_option('lib.num_threads', 4)
-
 
 class TestVersion(fixtures.TestCommon):
     """
@@ -1158,24 +1110,6 @@ class TestJp2k_write(fixtures.MetadataBase):
         with self.assertRaises(RuntimeError):
             j[:] = np.ones((100, 100), dtype=np.uint8)
 
-    @unittest.skipIf(os.cpu_count() < 2, "makes no sense if 2 cores not there")
-    def test_threads(self):
-        """
-        SCENARIO:  Attempt to encode with threading support.  This feature is
-        new as of openjpeg library version 2.4.0.
-
-        EXPECTED RESULT:  In library versions prior to 2.4.0, a warning is
-        issued.
-        """
-        glymur.set_option('lib.num_threads', 2)
-
-        with warnings.catch_warnings(record=True) as w:
-            Jp2k(self.temp_jp2_filename, data=self.jp2_data)
-            if glymur.version.openjpeg_version >= '2.4.0':
-                self.assertEqual(len(w), 0)
-            else:
-                self.assertEqual(len(w), 1)
-
     def test_capture_resolution(self):
         """
         SCENARIO:  The capture_resolution keyword is specified.
@@ -1335,11 +1269,7 @@ class TestJp2k_write(fixtures.MetadataBase):
 
         EXPECTED RESULT:  A TLM segment is detected.
         """
-        kwargs = {
-            'data': self.jp2_data,
-            'tlm': True
-        }
-        j = Jp2k(self.temp_jp2_filename, **kwargs)
+        j = Jp2k(self.temp_jp2_filename, data=self.jp2_data, tlm=True)
 
         codestream = j.get_codestream(header_only=False)
 
@@ -1355,11 +1285,24 @@ class TestJp2k_write(fixtures.MetadataBase):
 
         EXPECTED RESULT:  A TLM segment not detected.
         """
-        kwargs = {
-            'data': self.jp2_data,
-            'tlm': False
-        }
-        j = Jp2k(self.temp_jp2_filename, **kwargs)
+        j = Jp2k(self.temp_jp2_filename, data=self.jp2_data, tlm=False)
+
+        codestream = j.get_codestream(header_only=False)
+
+        at_least_one_tlm_segment = any(
+            isinstance(seg, glymur.codestream.TLMsegment)
+            for seg in codestream.segment
+        )
+        self.assertFalse(at_least_one_tlm_segment)
+
+    def test_tlm_none(self):
+        """
+        SCENARIO:  Use the tlm keyword set to None.  This was the default
+        position in 0.12.1.
+
+        EXPECTED RESULT:  A TLM segment not detected.
+        """
+        j = Jp2k(self.temp_jp2_filename, data=self.jp2_data, tlm=None)
 
         codestream = j.get_codestream(header_only=False)
 
@@ -1369,6 +1312,9 @@ class TestJp2k_write(fixtures.MetadataBase):
         )
         self.assertFalse(at_least_one_tlm_segment)
 
+    @unittest.skipIf(
+        glymur.version.openjpeg_version < '2.4.0', "Requires as least v2.4.0"
+    )
     @unittest.skipIf(
         not fixtures.HAVE_SCIKIT_IMAGE, fixtures.HAVE_SCIKIT_IMAGE_MSG
     )
@@ -1378,19 +1324,12 @@ class TestJp2k_write(fixtures.MetadataBase):
 
         EXPECTED RESULT:  Plt segment is detected.
         """
-        kwargs = {
-            'data': fixtures.skimage.data.camera(),
-            'plt': True
-        }
-        j = Jp2k(self.temp_jp2_filename, **kwargs)
+        j = Jp2k(self.temp_jp2_filename, data=self.j2k_data, plt=True)
 
         codestream = j.get_codestream(header_only=False)
 
-        at_least_one_plt = any(
-            isinstance(seg, glymur.codestream.PLTsegment)
-            for seg in codestream.segment
-        )
-        self.assertTrue(at_least_one_plt)
+        lst = [seg for seg in codestream.segment if seg.marker_id == 'PLT']
+        self.assertEqual(len(lst), 1)
 
     @unittest.skipIf(
         not fixtures.HAVE_SCIKIT_IMAGE, fixtures.HAVE_SCIKIT_IMAGE_MSG
@@ -1401,12 +1340,25 @@ class TestJp2k_write(fixtures.MetadataBase):
 
         EXPECTED RESULT:  Plt segment is not detected.
         """
-        kwargs = {
-            'data': fixtures.skimage.data.camera(),
-            'plt': False
-        }
-        j = Jp2k(self.temp_jp2_filename, **kwargs)
+        j = Jp2k(self.temp_jp2_filename, data=self.j2k_data, plt=False)
+        codestream = j.get_codestream(header_only=False)
 
+        at_least_one_plt = any(
+            isinstance(seg, glymur.codestream.PLTsegment)
+            for seg in codestream.segment
+        )
+        self.assertFalse(at_least_one_plt)
+
+    @unittest.skipIf(
+        not fixtures.HAVE_SCIKIT_IMAGE, fixtures.HAVE_SCIKIT_IMAGE_MSG
+    )
+    def test_plt_none(self):
+        """
+        SCENARIO:  Use the plt keyword set to None.
+
+        EXPECTED RESULT:  Plt segment is not detected.
+        """
+        j = Jp2k(self.temp_jp2_filename, data=self.j2k_data, plt=None)
         codestream = j.get_codestream(header_only=False)
 
         at_least_one_plt = any(
@@ -1653,11 +1605,54 @@ class TestJp2k_write(fixtures.MetadataBase):
         self.assertEqual(codestream.segment[2].precinct_size,
                          ((32768, 32768)))
 
+    def test_sop_explicitly_true(self):
+        """
+        Scenario:   Specify sop=True
+
+        Expected Result:  There are 17 SOP packets in the codestream.
+        """
+        j = Jp2k(self.temp_j2k_filename, data=self.jp2_data, sop=True)
+
+        codestream = j.get_codestream(header_only=False)
+
+        lst = [seg for seg in codestream.segment if seg.marker_id == 'SOP']
+        self.assertEqual(len(lst), 18)
+
+    def test_sop_explicitly_false(self):
+        """
+        Scenario:   Specify sop=False
+
+        Expected Result:  There are no SOP packets in the codestream.
+        """
+        j = Jp2k(self.temp_j2k_filename, data=self.jp2_data, sop=False)
+
+        codestream = j.get_codestream(header_only=False)
+
+        b = any(seg for seg in codestream.segment if seg.marker_id == 'SOP')
+        self.assertFalse(b)
+
+    def test_sop_explicitly_none(self):
+        """
+        Scenario:   Specify sop=None
+
+        Expected Result:  There are no SOP packets in the codestream.  This is
+        the old behavior.
+        """
+        j = Jp2k(self.temp_j2k_filename, data=self.jp2_data, sop=None)
+
+        codestream = j.get_codestream(header_only=False)
+
+        b = any(seg for seg in codestream.segment if seg.marker_id == 'SOP')
+        self.assertFalse(b)
+
     def test_NR_ENC_Bretagne2_ppm_6_encode(self):
         """
-        Original file tested was
+        Scenario:   Specify subsampling and writing SOP markers before each
+        packet.
 
-            input/nonregression/Bretagne2.ppm
+        Expected Result:  Subsampling is verified.  Usage of SOP is verified.
+        The original file tested in the openjpeg test suite was
+        input/nonregression/Bretagne2.ppm
         """
         j = Jp2k(
             self.temp_j2k_filename,
@@ -2196,8 +2191,28 @@ class TestJp2k_write(fixtures.MetadataBase):
         actdata = ofile[:]
         np.testing.assert_array_equal(actdata, expdata)
 
+    def test_write_srgb_specifying_mct_as_none(self):
+        """
+        Scenario:  Write RGB data, explicitly settimg mct to None, which is old
+        behavior.
+
+        Expected Result:  The codestream should record mct as being set.
+        """
+        j2k = Jp2k(self.j2kfile)
+        expdata = j2k[:]
+        ofile = Jp2k(self.temp_jp2_filename, data=expdata, mct=None)
+        actdata = ofile[:]
+        np.testing.assert_array_equal(actdata, expdata)
+
+        codestream = ofile.get_codestream()
+        self.assertEqual(codestream.segment[2].mct, 1)
+
     def test_write_srgb_without_mct(self):
-        """should be able to write RGB without specifying mct"""
+        """
+        Scenario:  Write RGB data, set mct to False.
+
+        Expected Result:  The codestream records mct as not being set.
+        """
         j2k = Jp2k(self.j2kfile)
         expdata = j2k[:]
         ofile = Jp2k(self.temp_jp2_filename, data=expdata, mct=False)
@@ -2209,7 +2224,10 @@ class TestJp2k_write(fixtures.MetadataBase):
 
     def test_write_grayscale_with_mct(self):
         """
-        MCT usage makes no sense for grayscale images.
+        Scenario:  Explicitly specify mct for a grayscale image.  The MCT does
+        not make sense there.
+
+        Expected Result:  RuntimeError
         """
         j2k = Jp2k(self.j2kfile)
         expdata = j2k[:]
@@ -2217,6 +2235,41 @@ class TestJp2k_write(fixtures.MetadataBase):
             with self.assertRaises(RuntimeError):
                 Jp2k(tfile.name, data=expdata[:, :, 0], mct=True)
 
+    def test_write_grayscale_with_mct_set_to_none(self):
+        """
+        Scenario:  Explicitly specify mct as None for a grayscale image.
+
+        Expected Result:  The MCT is not used.
+        """
+        j2k = Jp2k(self.j2kfile)
+        expdata = j2k[:][:, :, 2]
+
+        j = Jp2k(self.temp_jp2_filename, data=expdata, mct=None)
+
+        actdata = j[:]
+        np.testing.assert_array_equal(actdata, expdata)
+
+        codestream = j.get_codestream()
+        self.assertEqual(codestream.segment[2].mct, 0)  # no mct
+
+    def test_write_grayscale_with_mct_set_to_false(self):
+        """
+        Scenario:  Explicitly specify mct as False for a grayscale image.
+
+        Expected Result:  The MCT is not used.  That's the default for
+        grayscale anyway.
+        """
+        j2k = Jp2k(self.j2kfile)
+        expdata = j2k[:][:, :, 2]
+
+        j = Jp2k(self.temp_jp2_filename, data=expdata, mct=False)
+
+        actdata = j[:]
+        np.testing.assert_array_equal(actdata, expdata)
+
+        codestream = j.get_codestream()
+        self.assertEqual(codestream.segment[2].mct, 0)  # no mct
+
     def test_write_cprl(self):
         """Must be able to write a CPRL progression order file"""
         # Issue 17
