@@ -3,7 +3,6 @@
 Test suite for printing.
 """
 # Standard library imports ...
-import importlib.resources as ir
 from io import BytesIO, StringIO
 import struct
 import sys
@@ -23,7 +22,7 @@ from glymur.jp2box import BitsPerComponentBox, ColourSpecificationBox
 from glymur.jp2box import LabelBox
 from glymur import Jp2k, command_line
 from glymur.lib import openjp2 as opj2
-from . import fixtures, data
+from . import fixtures
 from .fixtures import OPENJPEG_NOT_AVAILABLE, OPENJPEG_NOT_AVAILABLE_MSG
 
 
@@ -57,10 +56,10 @@ class TestPrinting(fixtures.TestCommon):
         """
         Invalid channel type should not prevent printing.
         """
-        with ir.path(data, 'issue392.jp2') as path:
-            with warnings.catch_warnings():
-                warnings.simplefilter('ignore')
-                str(Jp2k(path))
+        path = fixtures._path_to('issue392.jp2')
+        with warnings.catch_warnings():
+            warnings.simplefilter('ignore')
+            str(Jp2k(path))
 
     def test_palette(self):
         """
@@ -1296,10 +1295,11 @@ class TestPrinting(fixtures.TestCommon):
 
         EXPECTED RESULT:  validate the string representation
         """
-        with ir.path(data, 'text_GBR.jp2') as path:
-            with self.assertWarns(UserWarning):
-                # The brand is wrong, this is JPX, not JP2.
-                j = Jp2k(path)
+        path = fixtures._path_to('text_GBR.jp2')
+        with self.assertWarns(UserWarning):
+            # The brand is wrong, this is JPX, not JP2.
+            j = Jp2k(path)
+
         box = j.box[3].box[1]
         actual = str(box)
         # Don't bother verifying the OrderedDict part of the colr box.
@@ -1506,27 +1506,27 @@ class TestPrinting(fixtures.TestCommon):
 
         EXPECTED RESULT:  validate the string representation
         """
-        with ir.path(data, 'p0_02.j2k') as path:
-            j = Jp2k(path)
+        path = fixtures._path_to('p0_02.j2k')
+        j = Jp2k(path)
         actual = str(j.codestream.segment[6])
         expected = '0xff30 marker segment @ (132, 0)'
         self.assertEqual(actual, expected)
 
     def test_scalar_implicit_quantization_file(self):
-        with ir.path(data, 'p0_03.j2k') as path:
-            j = Jp2k(path)
+        path = fixtures._path_to('p0_03.j2k')
+        j = Jp2k(path)
         actual = str(j.codestream.segment[3])
         self.assertIn('scalar implicit', actual)
 
     def test_scalar_explicit_quantization_file(self):
-        with ir.path(data, 'p0_06.j2k') as path:
-            j = Jp2k(path)
+        path = fixtures._path_to('p0_06.j2k')
+        j = Jp2k(path)
         actual = str(j.codestream.segment[3])
         self.assertIn('scalar explicit', actual)
 
     def test_non_default_precinct_size(self):
-        with ir.path(data, 'p1_07.j2k') as path:
-            j = Jp2k(path)
+        path = fixtures._path_to('p1_07.j2k')
+        j = Jp2k(path)
         actual = str(j.codestream.segment[3])
         expected = fixtures.P1_07
         self.assertEqual(actual, expected)
@@ -1653,8 +1653,8 @@ class TestJp2dump(unittest.TestCase):
         EXPECTED RESULT:  The warning is suppressed until the very end of the
         output.
         """
-        with ir.path(data, 'edf_c2_1178956.jp2') as path:
-            actual = self.run_jp2dump(['', '-x', str(path)])
+        path = fixtures._path_to('edf_c2_1178956.jp2')
+        actual = self.run_jp2dump(['', '-x', str(path)])
         lines = actual.splitlines()
 
         for line in lines[:-1]:
