@@ -1,9 +1,9 @@
 # standard library imports
-import importlib.resources as ir
 import pathlib
 import shutil
 import tempfile
 import unittest
+import warnings
 
 # 3rd party library imports
 import numpy as np
@@ -11,6 +11,7 @@ import numpy as np
 # local imports
 import glymur
 from glymur import Jp2k
+from . import fixtures
 from .fixtures import OPENJPEG_NOT_AVAILABLE, OPENJPEG_NOT_AVAILABLE_MSG
 
 
@@ -138,14 +139,17 @@ class TestSuite(unittest.TestCase):
         """
         SCENARIO:  Provide a negative component.
 
-        EXPECTED RESULT:  exception
+        EXPECTED RESULT:  An ValueError is raised.  There should not be any
+        warnings.
         """
 
         j2k = Jp2k(self.j2kfile)
 
-        with self.assertRaises(glymur.lib.openjp2.OpenJPEGLibraryError):
-            j2k.decoded_components = -1
-            j2k[:]
+        with self.assertRaises(ValueError):
+            with warnings.catch_warnings():
+                warnings.simplefilter('error')
+                j2k.decoded_components = -1
+                j2k[:]
 
     def test_same_component_several_times(self):
         """
@@ -180,19 +184,19 @@ class TestSuite(unittest.TestCase):
         setting decoded_components would require us to use the read_bands
         method.
         """
-        with ir.path('tests.data', 'p0_06.j2k') as path:
-            j2k = Jp2k(path)
+        path = fixtures._path_to('p0_06.j2k')
+        j2k = Jp2k(path)
 
-            expected = j2k.read_bands()[0]
+        expected = j2k.read_bands()[0]
 
-            j2k.decoded_components = 0
-            actual = j2k[:]
+        j2k.decoded_components = 0
+        actual = j2k[:]
 
-            np.testing.assert_array_equal(actual, expected)
+        np.testing.assert_array_equal(actual, expected)
 
         # verify that without using decoded components, we cannot read the
         # image using the slice protocol
-        with ir.path('tests.data', 'p0_06.j2k') as path:
-            j2k = Jp2k(path)
-            with self.assertRaises(RuntimeError):
-                j2k[:, :, 0]
+        path = fixtures._path_to('p0_06.j2k')
+        j2k = Jp2k(path)
+        with self.assertRaises(RuntimeError):
+            j2k[:, :, 0]
